@@ -5,7 +5,7 @@ import json
 import requests
 from sentry.plugins.bases.notify import NotificationPlugin
 
-import sentry_dingding
+import sentry_plugin_dingding
 from .forms import DingDingOptionsForm
 
 DingTalk_API = "https://oapi.dingtalk.com/robot/send?access_token={token}"
@@ -17,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'wangjinjie'
     author_url = 'http://gogs.visionacademy.cn/tools/sentry-plugin-dingding'
-    version = sentry_dingding.VERSION
+    version = sentry_plugin_dingding.VERSION
     description = 'Send error counts to DingDing.'
     resource_links = [
         ('Source', 'http://gogs.visionacademy.cn/tools/sentry-plugin-dingding'),
@@ -61,8 +61,7 @@ class DingDingPlugin(NotificationPlugin):
                 "text": u"#### {title} \n > {message} [href]({url})".format(
                     title=title,
                     message=event.message,
-                    url=u"{}events/{}/".format(group.get_absolute_url(),
-                                               event.event_id),
+                    url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                 )
             }
         }
